DataLad patches
***************

Patches that are automatically applied to DataLad when loading the
``datalad-next`` extension package.

.. currentmodule:: datalad_next.patches
.. autosummary::
   :toctree: generated

   add_method_url2transport_path
   annexrepo
   cli_configoverrides
   commanderror
   common_cfg
   configuration
   create_sibling_ghlike
   create_sibling_gitlab
   customremotes_main
   distribution_dataset
   fix_ria_ora_tests
   interface_utils
   patch_ria_ora
   push_optimize
   push_to_export_remote
   replace_create_sibling_ria
   replace_ora_remote
   replace_sshremoteio
   ria_utils
   run
   siblings
   ssh_exec
   sshconnector
   test_keyring
   update
